#
# spec file for package translate-toolkit
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
%define modname translate-toolkit
%define skip_python2 1
%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define binaries pocompile build_firefox.sh build_tmdb buildxpi.py csv2po csv2tbx flatxml2po get_moz_enUS.py html2po ical2po idml2po ini2po json2po junitmsgfmt l20n2po moz2po mozlang2po odf2xliff oo2po oo2xliff php2po phppo2pypo po2csv po2flatxml po2html po2ical po2idml po2ini po2json po2l20n po2moz po2mozlang po2oo po2php po2prop po2rc po2resx po2sub po2symb po2tiki po2tmx po2ts po2txt po2web2py po2wordfast po2xliff po2yaml poclean pocommentclean pocompendium poconflicts pocount podebug pofilter pogrep pomerge pomigrate2 popuretext poreencode porestructure posegment posplit poswap pot2po poterminology pretranslate prop2po pydiff pypo2phppo rc2po resx2po sub2po symb2po tbx2po tiki2po tmserver ts2po txt2po web2py2po xliff2odf xliff2oo xliff2po yaml2po
%define manpages pocompile build_firefox.sh csv2po csv2tbx flatxml2po html2po idml2po ini2po json2po junitmsgfmt moz2po mozlang2po odf2xliff oo2po oo2xliff phppo2pypo po2csv po2flatxml po2html po2idml po2ini po2json po2moz po2mozlang po2oo po2prop po2rc po2resx po2sub po2symb po2tiki po2tmx po2ts po2txt po2web2py po2wordfast po2xliff poclean poconflicts podebug pofilter pogrep pomerge porestructure posegment poswap pot2po poterminology pretranslate prop2po pypo2phppo rc2po resx2po sub2po symb2po tbx2po tiki2po translatetoolkit ts2po txt2po web2py2po xliff2odf xliff2oo xliff2po
Name:           translate-toolkit%{psuffix}
Version:        2.5.0
Release:        lp152.3.2
Summary:        Tools and API to assist with translation and software localization
License:        GPL-2.0-or-later
Group:          Development/Tools/Other
URL:            https://toolkit.translatehouse.org/
Source:         https://github.com/translate/translate/releases/download/%{version}/%{modname}-%{version}.tar.gz
# Repacked https://github.com/translate/sphinx-themes ; no commits since 2013
# Often not included in the release tag so just ship it
Source1:        sphinx-themes.tar.xz
Patch0:         sphinx-intersphinx.patch
Patch2:         xliff-xsd-no-network.patch
Patch3:         test-mo-endian.patch
# PATCH-FIX-UPSTREAM versioned_executables.patch mcepl@suse.com
# Use versioned partially installed executables
Patch4:         versioned_executables.patch
BuildRequires:  %{python_module Levenshtein >= 0.12}
BuildRequires:  %{python_module Sphinx}
BuildRequires:  %{python_module iniparse}
BuildRequires:  %{python_module l20n}
BuildRequires:  %{python_module lxml >= 3.5.0}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six >= 1.11.0}
BuildRequires:  %{python_module vobject}
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  gettext-runtime
BuildRequires:  git-core
BuildRequires:  iso-codes
BuildRequires:  python-rpm-macros
Requires:       gettext-runtime
Requires:       python-lxml
Requires:       python-pycountry >= 18.12.8
Requires:       python-pyenchant
Requires:       python-setuptools
Requires:       python-six >= 1.11.0
Requires(post): update-alternatives
Requires(postun): update-alternatives
# The following are for the full experience of translate-toolkit
Recommends:     gaupol
Recommends:     iso-codes
Recommends:     python-Levenshtein
Recommends:     python-aeidon
Recommends:     python-chardet
Recommends:     python-cheroot
Recommends:     python-iniparse
Recommends:     python-l20n
Recommends:     python-phply
Recommends:     python-pycountry
Recommends:     python-ruamel.yaml
Recommends:     python-vobject
Provides:       translate-toolkit = %{version}-%{release}
Obsoletes:      translate-toolkit < %{version}-%{release}
BuildArch:      noarch
%if %{with test}
BuildRequires:  %{python_module Babel}
BuildRequires:  %{python_module chardet}
BuildRequires:  %{python_module iniparse}
BuildRequires:  %{python_module pycountry >= 18.12.8}
BuildRequires:  %{python_module pyenchant}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module xml}
BuildRequires:  subversion
%if "%{python_flavor}" == "python2"
BuildRequires:  python2-backports.csv
%endif
%endif
%python_subpackages

%description
The Translate Toolkit is a set of software and documentation designed to help
make the lives of localizers both more productive and less frustrating.

The software includes programs to convert localization formats to the common
PO, and emerging XLIFF format.  There are also programs to check and manage PO
and XLIFF files.  Online documentation includes guides on using the tools,
running a localization project and how to localize various projects from
OpenOffice.org to Mozilla.

At its core the software contains a set of classes for handling various
localization storage formats: DTD, properties, OpenOffice.org GSI/SDF,
CSV, MO, Qt .ts, TMX, TBX, WordFast txt, Gettext .mo, Windows RC, and
of course PO and XLIFF.  It also provides scripts to convert between
these formats.

Also part of the Toolkit are Python programs to create word counts, merge
translations and perform various checks on translation files.

%package devel-doc
Summary:        Tools and API to assist with translation and software localization
Group:          Development/Libraries/Python
Requires:       %{name} = %{version}
Provides:       %{name}-devel = %{version}
Obsoletes:      %{name}-devel < %{version}
BuildArch:      noarch

%description devel-doc
The %{name}-devel-doc package contains Translate Toolkit API documentation for developers wishing to build new tools for the
toolkit or to use the libraries in other localization tools.

%prep
%setup -q -n %{modname}-%{version}
%autopatch -p1

pushd docs/_themes
tar -xJf %{SOURCE1} --strip 1
popd

sed -i 296"s|'share'|'translate/share'|" setup.py

#Fix for shebang errors:
for lib in translate/{*.py,*/*.py,*/*/*.py}; do
 sed -i '\|%{_bindir}/env |d' $lib
done

find . -name jquery.js -exec dos2unix '{}' \;

%build
%python_build
pushd docs
# Can't use parallel build here!
%make_build -j1 html man
#no hidden files
find _build -name '.?*' -delete
popd

%install
%python_install

# create manpages
mkdir -p %{buildroot}%{_mandir}/man1
for program in %{buildroot}%{_bindir}/*; do
    case $(basename $program) in
      pocompendium|poen|pomigrate2|popuretext|poreencode|posplit|pocount|poglossary|lookupclient.py|tmserver|build_tmdb)
        ;;
      *)
        MPAGE="%{buildroot}%{_mandir}/man1/$(basename $program).1"
        LC_ALL=C PYTHONPATH=. $program --manpage > "$MPAGE" || rm -f "$MPAGE"
        ;;
    esac
done
install -m 644 docs/_build/man/* %{buildroot}%{_mandir}/man1/

# move documentation files to datadir
%{python_expand install -d -m 755 %{buildroot}%{_defaultdocdir}/%{modname}
mv %{buildroot}%{$python_sitelib}/translate/docs/_build/html %{buildroot}%{_defaultdocdir}/%{modname}
rm -rf %{buildroot}%{$python_sitelib}/translate/docs
rm -rf %{buildroot}home/abuild/.local/lib/python%{$python_version}/site-packages/
}

# create symlinks for man pages
%fdupes -s %{buildroot}%{_mandir}
# create hardlinks for the rest
%python_expand %fdupes %{buildroot}%{$python_sitelib}

# Prepare alternatives
for mpage in %{manpages} ; do
%python_clone -a %{buildroot}%{_mandir}/man1/$mpage.1
done
for binary in %{binaries} ; do
%python_clone -a %{buildroot}%{_bindir}/$binary
done

%check
%if %{with test}
export PYTHONDONTWRITEBYTECODE=1
export PATH=$PATH:%{buildroot}%{_bindir}
%pytest tests
rm -rf %{buildroot}
%endif

%post
%define my_install_alternatives() %{lua:\
    function file_exists(path) \
    	local f = io.open(path) \
    	if f == nil then return false \
    	else f:close() return true  \
    	end \
    end \
    local t={} \
    local manpath = "" \
    for str in string.gmatch(rpm.expand("%**"), "([^%s]+)") do \
            table.insert(t, str) \
    end \
    local bindir = rpm.expand("%{_bindir}") \
    local mandir = rpm.expand("%{_mandir}") .. "/man1" \
    local ver_ext = "-" .. t[1] \
    local man_ext = ".1" .. rpm.expand("%{?ext_man}") \
    local man_ext_ver = ver_ext .. man_ext \
    \
    local ua_cmd = "update-alternatives --install " .. mandir .. "/translatetoolkit" .. man_ext .. " translatetoolkit.1 " .. \
        mandir .. "/translatetoolkit" .. man_ext_ver .. " 20 \\\\\\n" \
    local elems = table.pack(table.unpack(t, 2)) \
    for arg, name in ipairs(elems) do \
        ua_cmd = ua_cmd .. " --slave " .. bindir .. "/" .. name .. " " .. name .. " " .. bindir .. "/" .. name .. ver_ext .. " \\\\\\n" \
        manpath = mandir .. "/" .. name .. man_ext_ver \
        if file_exists(manpath) then \
            ua_cmd = ua_cmd .. " --slave " .. mandir .. "/" .. name .. man_ext .. " " .. name .. ".1 " .. manpath .. " \\\\\\n" \
        end \
    end\
    -- we need to remove the last backslash and EOL \
    print(ua_cmd:sub(1, -3)) \
}
%my_install_alternatives %{_rec_macro_helper}%{lua:expand_macro("version")} %binaries


%postun
if [ ! -f %{_mandir}/man1/translatetoolkit-%{_rec_macro_helper}%{lua:expand_macro("version")}.1%{?ext_man} ] ; then
   update-alternatives --remove translatetoolkit %{_mandir}/man1/translatetoolkit-%{_rec_macro_helper}%{lua:expand_macro("version")}.1%{?ext_man}
fi

%if !%{with test}
%files %{python_files}
%dir %{_defaultdocdir}/%{modname}
%{_defaultdocdir}/%{modname}/html/
%exclude %{_defaultdocdir}/%{modname}/html/api
%exclude %{_defaultdocdir}/%{modname}/html/_sources
%license COPYING
%doc README.rst
%ghost %{_sysconfdir}/alternatives/*
%{_bindir}/*
%{_mandir}/man1/*
%{python_sitelib}/translate
%{python_sitelib}/translate_toolkit-%{version}-*.egg-info

%files devel-doc
%doc %{_defaultdocdir}/%{modname}/html/api
%doc %{_defaultdocdir}/%{modname}/html/_sources
%endif

%changelog
* Wed May 13 2020 Matej Cepl <mcepl@suse.com>
- Clean up, rewrite to single-spec style, and use %%pytest macro.
- We have to install, but remove afterwards, when in the test phase.
- Add versioned_executables.patch to use partially installed
  versioned executables.
* Fri May  1 2020 Matej Cepl <mcepl@suse.com>
- Swtich to multibuild to separate tests
* Wed Mar 18 2020 Andreas Schwab <schwab@linux-m68k.org>
- test-mo-endian.patch: tell msgfmt to use correct endianness
* Tue Mar  3 2020 Ondřej Súkup <mimi.vx@gmail.com>
- temporary disable TestYAMLResourceStore.test_empty_key because
  ruamel.yaml has different behaviour on empty keys from version
    0.16.6
* Wed Jan 22 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.5.0:
  * Fixes to work with new weblate
* Thu Jul 11 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.4.0:
  * Added new Flat XML format and converters.
  * Fixes for multiple formats.
- Remove merged patches:
  * pycountry.patch
  * test-pytest310.patch
* Thu Apr  4 2019 Tomáš Chvátal <tchvatal@suse.com>
- Do not depend on strace, it is not really needed
* Fri Mar 29 2019 Tomáš Chvátal <tchvatal@suse.com>
- Add patch to build with current pycountry:
  * pycountry.patch
* Wed Mar  6 2019 Tomáš Chvátal <tchvatal@suse.com>
- Drop not needed lxml-doc dependency
* Mon Jan 28 2019 Jan Engelhardt <jengelh@inai.de>
- Avoid mixing historic and modern option syntax for tar.
- Replace find -exec rm by just find -delete.
* Mon Jan 28 2019 Luiz Fernando Ranghetti <elchevive68@gmail.com>
- Correct the Source URL
* Thu Jan 10 2019 Tomáš Chvátal <tchvatal@suse.com>
- Make sure the documentation is generated properly
- Enable testsuite
- Add patches from debian for tests to pass:
  * sphinx-intersphinx.patch
  * test-pytest310.patch
  * xliff-xsd-no-network.patch
* Tue Dec 18 2018 sbrabec@suse.com
- Update to 2.3.1:
  * But fixes.
  * INI: Enabled support for Python3 provided.
  * Use backports.csv module on Python 2 to align the behavior
    with Python 3 and drop many hacks.
  * Removed deprecated getoutput, add new depreceations.
  * Code cleanup; many converterters refactored.
* Wed Mar 21 2018 elchevive@opensuse.org
- update to 2.3.0
  * Full rewrite of the PHP format greatly extending the support.
  * Added YAML format converters.
  * Major refactor of converters code.
- drop patch translate-toolkit-2.0.0-python-six.diff not needed
  on Leap 15.0
* Tue Dec 26 2017 astieger@suse.com
- update to 2.2.5:
  * Fixed bug when adding new units to XLIFF store.
  * Added support for i18next JSON dialect.
  * Improved WebExtension JSON dialect support.
* Tue Nov 14 2017 jmatejek@suse.com
- drop unneeded requirement for python-utidy
- drop unneeded requirements for diff_match_patch
- switch to python3
* Mon Aug 28 2017 elchevive@opensuse.org
- Update do 2.2.4
  * Added support for nested and WebExtension JSON dialects.
  * po2txt no longer converts non-translatable strings.
  * Improvement for puncspace check.
  * Support for .xliff extension.
* Mon Jun 26 2017 elchevive@opensuse.org
- Update do 2.2.3
  * Added MinimalChecker and ReducedChecker checkers.
  * Fixed resolving of country names translations.
  * Refactored functions for resolving language/country names translation to be memory efficient.
  * Improvements for ts and subtitles formats.
  * Added –preserveplaceholders argument to podebug.
  * Fixed Montenegrin language name.
* Fri Jun 16 2017 elchevive@opensuse.org
- add python-pycountry as Requires
- Update do 2.2.0
  * Avoid resolving external entities while parsing XML.
  * Improvements for Android, ts and resx formats.
  * Added support for PHP nested arrays.
  * Added Kabyle language
* Mon Mar 20 2017 elchevive@opensuse.org
- Update do 2.1.0
  * Fixed RomanianChecker checks.
  * Added an iOS checker style.
  * Changed plural equations for Slovenian, Persian, Kazakh and Kyrgyz.
  * Several fixes in formats and tools.
* Mon Mar  6 2017 lnussel@suse.de
- lower python-six requirement to 1.9 again to make translate-toolkit work on
  Leap. There is no real requirement on 1.10:
  https://github.com/translate/translate/pull/3488
  * translate-toolkit-2.0.0-python-six.diff
* Sun Feb 26 2017 dimstar@opensuse.org
- Explicitly package %%{_defaultdocdir}/%%{name}/html: fix build with
  RPM 4.13.
* Mon Jan 30 2017 elchevive@opensuse.org
- Update do 2.0.0
  * po2txt works correctly again when --threshold option is passed
  (https://github.com/translate/translate/issues/3499) boo#999286
* Tue Jan 24 2017 elchevive@opensuse.org
- Add missing Requires: python-setuptools
* Mon Jan 16 2017 elchevive@opensuse.org
- Update to 1.99.9 (2.0.0 RC2)
  * Minor fixes
* Thu Sep  1 2016 elchevive@opensuse.org
- Update to 1.99.5 (2.0.0 Beta 5)
  * Minor fixes
- require lxml 3.5.0 or newer
* Wed Jul 27 2016 buschmann23@opensuse.org
- Update to 1.99.3 (2.0.0 Beta 3)
  * Python 3 compatibility thanks to Claude Paroz
  * Dropped support for Python 2.6
  * Changes in storage API to expose a more standardized API
- require python 2.7 or newer
* Thu Apr 28 2016 michal@cihar.com
- Update to 1.14.0-rc1
* Tue Nov 10 2015 mcihar@suse.cz
- Fix documentation build (breaks in parallel build)
* Tue Nov 10 2015 mcihar@suse.cz
- python-six is required for build as well (for API docs)
* Tue Nov 10 2015 mcihar@suse.cz
- Remove Sphinx build cache before building docs
* Wed Jul 29 2015 dimstar@opensuse.org
- Require python-six: translate/misc/quote.py depends on it.
* Wed Jul 15 2015 mcihar@suse.cz
- use spec-cleaner to sort dependencies
* Wed Jul 15 2015 mcihar@suse.cz
- make dependency on several optional features only recommended: vobject,
  Levenshtein, aeidon, iniparse
- remove not needed xapian build dependency
- remove not used simplejson from build/runtime dependencies
* Fri May 15 2015 elchevive@opensuse.org
- updated to version 1.13.0
- updated Source URL and run spec-cleaner
  Major changes
  New converters for IDML format
  Support for new .Net Resource (.resx) format
  Extensive cleanup on ODF converters
  New quality checks
    Some bugfixes and improvements
* Thu Nov  6 2014 mcihar@suse.cz
- remove not needed gaupol build dependency
* Tue Aug 12 2014 elchevive@opensuse.org
- updated to version 1.12.0
  Major changes
  Properties and DTD formats fix a number of issues
  Massive code cleanup looking forward Python 3 compatibility
  Important changes in development process to ease testing
* Thu Jan 30 2014 elchevive@opensuse.org
- updated to version 1.11.0
  Major changes:
  The PO format now matches Gettext more closely
  PHP format adds a number of new features
  Support for Python 2.5 has been dropped
* Sun Jul 14 2013 elchevive@opensuse.org
- add 2 missing BuildRequires (python-Levenshtein and change
  python-aeidon with gaupol)
* Fri Jun 28 2013 elchevive@opensuse.org
- Add python-{Levenshtein,aeidon} as Requires and remove again
  diff_match_patch as its not allowed on Factory (license issue)
* Tue Mar 26 2013 fa0sck@gmail.com
- New upstream version (1.10.0)
  * devel package renamed as devel-doc.
* Sat Jan 12 2013 dmitry.rojkov@gmail.com
- initial repackaging
* Tue Jun  5 2012 i@marguerite.su
- fix sles builds.
  * version tag for buildarch: noarch.
* Thu May 10 2012 elchevive@opensuse.org
- Remove psyco references as it is a dead project
* Thu Apr 19 2012 elchevive@opensuse.org
- Add Provides: python-translate-toolkit for compatibility with old packages
* Mon Mar 26 2012 elchevive@opensuse.org
- Cosmetic change in 'for' used to remove shebangs
* Tue Mar 20 2012 elchevive@opensuse.org
- Add proper specfile header as requested in sr#109322
* Wed Mar 14 2012 elchevive@opensuse.org
- Fix for bnc#750652 (remove Apache-2.0 file as the programa has a fallbak)
* Sun Feb 26 2012 elchevive@opensuse.org
- Add ifelse to python-pyenchant (new name for > 12.1)
* Wed Feb 22 2012 elchevive@opensuse.org
- Fix the non-executable-script warning
* Wed Apr 13 2011 elchevive@opensuse.org
- Updated to version 1.9.0
  Highlighted improvements
  - Faster terminology matching
  - Several small optimisations to performance and memory use
  - More advanced state support (visible in pocount and Virtaal 0.7)
  - Improved language detection models (+South African languages)
  - Improve handling of printf variable reordering [Jacques Beaurain]
  - Review of the wording of the messages of pofilter checks
  - Better sentence segmentation for some non-Latin languages
  - More supported formats for podebug
  - Extra options for pomerge, pogrep and po2oo/xliff2oo. The new pogrep options made this possible for GNOME: http://translate.org.za/blogs/friedel/en/content/better-lies-about-gnome-localisation
  Most relevant for Pootle:
  - Support for Xapian 1.2 (bug 1766) [Rimas Kudelis]
  - Work around some changes introduced in Django 1.2.5/1.3
  Format support:
  - Always use UNIX line endings for PO (even on Windows)
  - XLIFF and .ts files now shows "fuzzy" only the target present
  - Improved support for .ts comment as context (bug 1739)
  - Support for Java properties in UTF-8 encoding
  - More natural string ordering in json converter
  - Improved handling of trailing spaces in Mozilla DTD files
  - Removed unused support for _old_ KDE plurals in pocount
  ...and several small bugfixes
* Mon Dec 27 2010 elchevive@opensuse.org
- Removed 11.1 references and python- prefix
* Fri Nov 19 2010 elchevive@opensuse.org
- Updated to version 1.8.1
* Tue Aug 17 2010 elchevive@opensuse.org
- Updated to version 1.8.0
- Set Gaupol as Suggestion
* Wed May 12 2010 elchevive@opensuse.org
- Updated to version 1.7.0
* Fri Mar  5 2010 elchevive@opensuse.org
- Updated to version 1.6.0
- Added python-enchant as Requires
* Tue Feb 23 2010 elchevive@opensuse.org
- Rename -doc to -devel (as it is devel's docs)
- Added more requires (for ical2po, sub2po work)
- Remove duplicated docs in -devel
* Mon Feb 22 2010 elchevive@opensuse.org
- Package split (-doc) and manpages created (using Fedora's .spec)
* Tue Feb 16 2010 elchevive@opensuse.org
- Package updated to version 1.5.3
* Mon Jan 25 2010 elchevive@opensuse.org
- Added gettext-runtime as requirement
* Wed Jan 20 2010 elchevive@opensuse.org
- Added python-lxml as requirement
* Thu Jan 14 2010 elchevive@opensuse.org
- Initial release 1.5.2 - spec/rpmlint copyed from thomas-schaite repository
